@@ -29,6 +29,7 @@ full_p <- area_profiles(df,
                         local_area_code = "AC122",
                         indicator = IndicatorName,
                         timeperiod = Timeperiod,
+                        trend = Trend,
                         polarity = Polarity,
                         significance = Significance,
                         area_type = AreaType,
@@ -40,18 +41,45 @@ full_p <- area_profiles(df,
                         bar_width = 0.68,
                         indicator_label_nudgex = -0.1,
                         show_dividers = "outer",
-                        header_positions = c(-0.7, -0.44, -0.35, -0.25,
+                        header_positions = c(-1, -0.7, -0.44, -0.35, -0.25,
                             -0.15, -0.05, 1.08)
 )
 
+full_p_no_trend <- area_profiles(df,
+                        value = Value,
+                        count = Count,
+                        area_code = AreaCode,
+                        local_area_code = "AC100",
+                        indicator = IndicatorName,
+                        timeperiod = Timeperiod,
+                        polarity = Polarity,
+                        significance = Significance,
+                        area_type = AreaType,
+                        median_line_area_code = "C001",
+                        comparator_area_code = "PAC12",
+                        datatable = TRUE,
+                        relative_domain_text_size = 0.75,
+                        relative_text_size = 1.2,
+                        bar_width = 0.68,
+                        indicator_label_nudgex = -0.1,
+                        show_dividers = "outer",
+                        header_positions = c(-0.7, -0.7, -0.44, -0.35, -0.25,
+                                             -0.15, -0.05, 1.08),
+                        header_labels = c("Indicator", "",
+                                          "Time\nperiod", "Local\ncount",
+                                          "Local\nvalue", "England\nvalue",
+                                          "Worst/\nLowest", "Best/\nHighest")
+)
+
 full_with_factor_indicators_p <- suppressWarnings(
         area_profiles(df2,
                       value = Value,
                       count = Count,
                       area_code = AreaCode,
-                      local_area_code = "AC122",
+                      local_area_code = "AC100",
                       indicator = IndicatorName,
                       timeperiod = Timeperiod,
+                      trend = Trend,
                       polarity = Polarity,
                       significance = Significance,
                       area_type = AreaType,
@@ -63,7 +91,7 @@ full_with_factor_indicators_p <- suppressWarnings(
                       bar_width = 0.68,
                       indicator_label_nudgex = -0.1,
                       show_dividers = "outer",
-                      header_positions = c(-0.7, -0.53, -0.35, -0.25,
+                      header_positions = c(-1, -0.7, -0.53, -0.35, -0.25,
                                            -0.15, -0.05, 1.08))
 )
 
@@ -75,6 +103,7 @@ full_no_dt_p <- area_profiles(df,
                               local_area_code = "AC122",
                               indicator = IndicatorName,
                               timeperiod = Timeperiod,
+                              trend = Trend,
                               polarity = Polarity,
                               significance = Significance,
                               area_type = AreaType,
@@ -83,6 +112,23 @@ full_no_dt_p <- area_profiles(df,
                               bar_width = 0.68,
                               datatable = FALSE)
 
+full_no_dt_p_modified_colours <- area_profiles(df,
+                                               value = Value,
+                                               count = Count,
+                                               area_code = AreaCode,
+                                               local_area_code = "AC122",
+                                               indicator = IndicatorName,
+                                               timeperiod = Timeperiod,
+                                               trend = Trend,
+                                               polarity = Polarity,
+                                               significance = Significance,
+                                               area_type = AreaType,
+                                               cols = c("Worse" = "purple"),
+                                               median_line_area_code = "C001",
+                                               comparator_area_code = "PAC12",
+                                               bar_width = 0.68,
+                                               datatable = FALSE)
+
 full_with_domains_p <- area_profiles(df,
                                      value = Value,
                                      count = Count,
@@ -90,6 +136,7 @@ full_with_domains_p <- area_profiles(df,
                                      local_area_code = "AC122",
                                      indicator = IndicatorName,
                                      timeperiod = Timeperiod,
+                                     trend = Trend,
                                      polarity = Polarity,
                                      significance = Significance,
                                      area_type = AreaType,
@@ -101,7 +148,7 @@ full_with_domains_p <- area_profiles(df,
                                      bar_width = 0.68,
                                      indicator_label_nudgex = -0.1,
                                      show_dividers = "outer",
-                                     header_positions = c(-0.7, -0.53, -0.35, -0.25,
+                                     header_positions = c(-1, -0.7, -0.53, -0.35, -0.25,
                                                           -0.15, -0.05, 1.05),
                                      domain = Domain)
 
@@ -112,6 +159,7 @@ full_all_dividers_p <- area_profiles(df,
                                      local_area_code = "AC122",
                                      indicator = IndicatorName,
                                      timeperiod = Timeperiod,
+                                     trend = Trend,
                                      polarity = Polarity,
                                      significance = Significance,
                                      area_type = AreaType,
@@ -122,7 +170,7 @@ full_all_dividers_p <- area_profiles(df,
                                      bar_width = 0.68,
                                      indicator_label_nudgex = -0.1,
                                      show_dividers = "all",
-                                     header_positions = c(-0.7, -0.53, -0.35, -0.25,
+                                     header_positions = c(-1, -0.7, -0.53, -0.35, -0.25,
                                                           -0.15, -0.05, 1.05))
 
 dps_p <- area_profiles(df_dps,
@@ -132,6 +180,7 @@ dps_p <- area_profiles(df_dps,
                        local_area_code = "AC122",
                        indicator = IndicatorName,
                        timeperiod = Timeperiod,
+                       trend = Trend,
                        polarity = Polarity,
                        significance = Significance,
                        area_type = AreaType,
@@ -143,7 +192,7 @@ dps_p <- area_profiles(df_dps,
                        bar_width = 0.68,
                        indicator_label_nudgex = -0.1,
                        show_dividers = "outer",
-                       header_positions = c(-0.7, -0.44, -0.35, -0.25,
+                       header_positions = c(-1, -0.7, -0.44, -0.35, -0.25,
                                             -0.15, -0.05, 1.08),
                        dps = NA)
 
@@ -155,6 +204,7 @@ test_that("Error for duplicate values in spine chart works", {
                                    local_area_code = "AC122",
                                    indicator = IndicatorName,
                                    timeperiod = Timeperiod,
+                                   trend = Trend,
                                    polarity = Polarity,
                                    significance = Significance,
                                    area_type = AreaType,
@@ -176,6 +226,12 @@ test_that("full area profiles draws correctly", {
         )
 })
 
+test_that("full area profiles draws correctly with no trends information", {
+        vdiffr::expect_doppelganger("full area profiles no trend",
+                                    full_p_no_trend
+        )
+})
+
 test_that("full area profiles with factor indicator name draws correctly", {
         vdiffr::expect_doppelganger("full with factor area profiles",
                                     full_with_factor_indicators_p
@@ -188,7 +244,11 @@ test_that("area profiles with no dt draws correctly", {
         )
 })
 
-
+test_that("area profiles with colour modification draws correctly", {
+        vdiffr::expect_doppelganger("modified colours area profiles",
+                                    full_no_dt_p_modified_colours
+        )
+})
 
 test_that("area profiles with domains draws correctly", {
         vdiffr::expect_doppelganger("domains included area profiles",
@@ -210,6 +270,7 @@ test_that("error messages work for area_profiles", {
                                    local_area_code = "BB2",
                                    indicator = IndicatorName,
                                    timeperiod = Timeperiod,
+                                   trend = Trend,
                                    polarity = Polarity,
                                    significance = Significance,
                                    area_type = AreaType,
@@ -222,6 +283,7 @@ test_that("error messages work for area_profiles", {
                                    local_area_code = "AC122",
                                    indicator = IndicatorName,
                                    timeperiod = Timeperiod,
+                                   trend = Trend,
                                    polarity = Polarity,
                                    significance = Significance,
                                    area_type = AreaType,
@@ -234,12 +296,52 @@ test_that("error messages work for area_profiles", {
                                    local_area_code = "AC122",
                                    indicator = IndicatorName,
                                    timeperiod = Timeperiod,
+                                   trend = Trend,
                                    polarity = Polarity,
                                    significance = Significance,
                                    area_type = AreaType,
                                    median_line_area_code = "C001",
                                    comparator_area_code = "CB1"),
                      "CB1 not in area_code field provided")
+        expect_error(full_no_dt_p <- area_profiles(df,
+                                                   value = Value,
+                                                   count = Count,
+                                                   area_code = AreaCode,
+                                                   local_area_code = "AC122",
+                                                   indicator = IndicatorName,
+                                                   timeperiod = Timeperiod,
+                                                   trend = Trend,
+                                                   polarity = Polarity,
+                                                   significance = Significance,
+                                                   area_type = AreaType,
+                                                   median_line_area_code = "C001",
+                                                   comparator_area_code = "PAC12",
+                                                   header_labels = c("Indicator", "Time\nperiod",
+                                                                     "Local\ncount", "Local\nvalue",
+                                                                     "England\nvalue", "Worst/\nLowest",
+                                                                     "Best/\nHighest"),
+                                                   bar_width = 0.68,
+                                                   datatable = FALSE),
+                     "header_labels argument must have a length of 8")
+        expect_error(full_no_dt_p <- area_profiles(df,
+                                                   value = Value,
+                                                   count = Count,
+                                                   area_code = AreaCode,
+                                                   local_area_code = "AC122",
+                                                   indicator = IndicatorName,
+                                                   timeperiod = Timeperiod,
+                                                   trend = Trend,
+                                                   polarity = Polarity,
+                                                   significance = Significance,
+                                                   area_type = AreaType,
+                                                   median_line_area_code = "C001",
+                                                   comparator_area_code = "PAC12",
+                                                   header_positions  = c(-1.83, -0.53,
+                                                                         -0.35, -0.25,
+                                                                         -0.15, -0.05, 1.05),
+                                                   bar_width = 0.68,
+                                                   datatable = FALSE),
+                     "header_positions argument must have a length of 8")
 })
 
 test_that("warning messages work for area_profiles", {
@@ -250,6 +352,7 @@ test_that("warning messages work for area_profiles", {
                                      local_area_code = "AC122",
                                      indicator = IndicatorName,
                                      timeperiod = Timeperiod,
+                                     trend = Trend,
                                      polarity = Polarity,
                                      significance = Significance,
                                      area_type = AreaType,
@@ -261,7 +364,7 @@ test_that("warning messages work for area_profiles", {
                                      bar_width = 0.68,
                                      indicator_label_nudgex = -0.1,
                                      show_dividers = "outer",
-                                     header_positions = c(-0.7, -0.44, -0.35, -0.25,
+                                     header_positions = c(-1, -0.7, -0.44, -0.35, -0.25,
                                                           -0.15, -0.05, 0.9),
                                      dps = NA),
                      "Some bars may not display if the final value of the header_positions argument is less than 1")
